==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/CollectiveRunCore/src/com/clustercontrol/collectiverun/core/CollectiveRunCorePlugin.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.collectiverun.core;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * 浡ǽץ饰󥯥饹Ǥ
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class CollectiveRunCorePlugin extends AbstractUIPlugin {

    // ----- static ե ----- //

    //	The shared instance.
    private static CollectiveRunCorePlugin plugin;

    // ----- instance ե----- //

    //	Resource bundle.
    private ResourceBundle resourceBundle;

    /**
     * 󥹥ȥ饯
     *  
     */
    public CollectiveRunCorePlugin() {
        super();
        plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.collectiverun.core.CollectiveRunCorePluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
    }

    /**
     * This method is called upon plug-in activation
     * 
     * @param context
     * @throws Exception
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     * 
     * @param context
     * @throws Exception
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * Returns the shared instance.
     * 
     * @return plugin
     */
    public static CollectiveRunCorePlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the string from the plugin's resource bundle, or 'key' if not
     * found.
     * 
     * @param key
     * @return key
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = CollectiveRunCorePlugin.getDefault()
                .getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * Returns the plugin's resource bundle,
     * 
     * @return resouceBundle
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/CollectiveRunCore/src/com/clustercontrol/collectiverun/core/CollectiveRunCorePlugin.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.collectiverun.core;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * 一括制御機能プラグインクラスです
 * 
 * @version 1.0.0
 * @since 1.0.0
 */
public class CollectiveRunCorePlugin extends AbstractUIPlugin {

    // ----- static フィールド ----- //

    //	The shared instance.
    private static CollectiveRunCorePlugin plugin;

    // ----- instance フィールド----- //

    //	Resource bundle.
    private ResourceBundle resourceBundle;

    /**
     * コンストラクタ
     *  
     */
    public CollectiveRunCorePlugin() {
        super();
        plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("com.clustercontrol.collectiverun.core.CollectiveRunCorePluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
    }

    /**
     * This method is called upon plug-in activation
     * 
     * @param context
     * @throws Exception
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     * 
     * @param context
     * @throws Exception
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * Returns the shared instance.
     * 
     * @return plugin
     */
    public static CollectiveRunCorePlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the string from the plugin's resource bundle, or 'key' if not
     * found.
     * 
     * @param key
     * @return key
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = CollectiveRunCorePlugin.getDefault()
                .getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * Returns the plugin's resource bundle,
     * 
     * @return resouceBundle
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}
